You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openwebbeans.apache.org by ge...@apache.org on 2009/08/30 15:07:36 UTC

svn commit: r809329 - in /incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise: context/ context/spi/ inject/spi/

Author: gerdogdu
Date: Sun Aug 30 13:07:36 2009
New Revision: 809329

URL: http://svn.apache.org/viewvc?rev=809329&view=rev
Log:
Changing @ScopeType to @Scope and @NormalScope

Added:
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java   (contents, props changed)
      - copied, changed from r806816, incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ScopeType.java
Removed:
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ScopeType.java
Modified:
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ApplicationScoped.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ConversationScoped.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/Dependent.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/RequestScoped.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/SessionScoped.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/spi/Context.java
    incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/spi/BeanManager.java

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ApplicationScoped.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ApplicationScoped.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ApplicationScoped.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ApplicationScoped.java Sun Aug 30 13:07:36 2009
@@ -27,7 +27,7 @@
  * of the specification.
  * </p>
  */
-@ScopeType
+@NormalScope
 @Target( { ElementType.TYPE, ElementType.METHOD })
 @Retention(RetentionPolicy.RUNTIME)
 @Inherited

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ConversationScoped.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ConversationScoped.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ConversationScoped.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ConversationScoped.java Sun Aug 30 13:07:36 2009
@@ -24,7 +24,7 @@
  * 
  * @see Conversation
  */
-@ScopeType(passivating=true)
+@NormalScope(passivating=true)
 @Target( { ElementType.TYPE, ElementType.METHOD })
 @Retention(RetentionPolicy.RUNTIME)
 @Inherited

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/Dependent.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/Dependent.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/Dependent.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/Dependent.java Sun Aug 30 13:07:36 2009
@@ -19,6 +19,8 @@
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
+import javax.inject.Scope;
+
 /**
  * Dependent scope type.
  * <p>
@@ -37,7 +39,7 @@
  * </p>
  * 
  */
-@ScopeType(normal = false)
+@Scope
 @Target( { ElementType.TYPE, ElementType.METHOD, ElementType.FIELD })
 @Retention(RetentionPolicy.RUNTIME)
 @Inherited

Copied: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java (from r806816, incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ScopeType.java)
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java?p2=incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java&p1=incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ScopeType.java&r1=806816&r2=809329&rev=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/ScopeType.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java Sun Aug 30 13:07:36 2009
@@ -20,14 +20,17 @@
 import java.lang.annotation.Retention;
 import java.lang.annotation.Target;
 
+/**
+ * Defines normal scoped meta-data.
+ * 
+ * @version $Rev$ $Date$
+ *
+ */
 @Target(ANNOTATION_TYPE)
 @Retention(RUNTIME)
 @Documented
-public @interface ScopeType
+public @interface NormalScope
 {
-
-    boolean normal() default true;
-
+    /**Defines passivation semantic*/
     boolean passivating() default false;
-
 }

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/NormalScope.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/RequestScoped.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/RequestScoped.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/RequestScoped.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/RequestScoped.java Sun Aug 30 13:07:36 2009
@@ -34,7 +34,7 @@
 @Target( { TYPE, METHOD, FIELD })
 @Retention(RUNTIME)
 @Documented
-@ScopeType
+@NormalScope
 @Inherited
 public @interface RequestScoped
 {

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/SessionScoped.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/SessionScoped.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/SessionScoped.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/SessionScoped.java Sun Aug 30 13:07:36 2009
@@ -26,7 +26,7 @@
 @Target( { TYPE, METHOD, FIELD})
 @Retention(RUNTIME)
 @Documented
-@ScopeType(passivating=true)
+@NormalScope(passivating=true)
 @Inherited
 public @interface SessionScoped
 {

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/spi/Context.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/spi/Context.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/spi/BeanManager.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/spi/BeanManager.java Sun Aug 30 13:07:36 2009
@@ -20,7 +20,6 @@
 import java.util.Set;
 
 import javax.el.ELResolver;
-import javax.enterprise.context.ScopeType;
 import javax.enterprise.context.spi.Context;
 import javax.enterprise.context.spi.Contextual;
 import javax.enterprise.context.spi.CreationalContext;
@@ -208,7 +207,24 @@
      * @param annotationType annotation type
      * @return true if given type is a scope type, false otherwise
      */
-    public boolean isScopeType(Class<? extends Annotation> annotationType);
+    public boolean isScope(Class<? extends Annotation> annotationType);
+    
+    /**
+     * Returns true if given type is a normal scope type, false otherwise.
+     * 
+     * @param annotationType annotation type
+     * @return true if given type is a scope type, false otherwise
+     */
+    public boolean isNormalScope(Class<? extends Annotation> annotationType);
+    
+    /**
+     * Returns true if given type is a passivating scope type, false otherwise.
+     * 
+     * @param annotationType annotation type
+     * @return true if given type is a scope type, false otherwise
+     */
+    public boolean isPassivatingScope(Class<? extends Annotation> annotationType);    
+    
 
     /**
      * Returns true if given type is a binding type, false otherwise.
@@ -216,7 +232,7 @@
      * @param annotationType annotation type
      * @return true if given type is a binding type, false otherwise
      */    
-    public boolean isBindingType(Class<? extends Annotation> annotationType);
+    public boolean isQualifier(Class<? extends Annotation> annotationType);
     
     /**
      * Returns true if given type is a interceptor binding type, false otherwise.
@@ -234,15 +250,7 @@
      * @return true if given type is a stereotype, false otherwise
      */
     public boolean isStereotype(Class<? extends Annotation> annotationType);
-    
-    /**
-     * Gets a scope type annotation.
-     * 
-     * @param scopeType scope class type
-     * @return a scope type annotation
-     */
-    public ScopeType getScopeDefinition(Class<? extends Annotation> scopeType);
-    
+        
     /**
      * Returns a set of meta-annotations that are defined on the binding type
      *
--- incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/spi/Context.java (original)
+++ incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/context/spi/Context.java Sun Aug 30 13:07:36 2009
@@ -16,11 +16,11 @@
 import java.lang.annotation.Annotation;
 
 import javax.enterprise.context.ContextNotActiveException;
-import javax.enterprise.context.ScopeType;
+import javax.enterprise.context.NormalScope;
 
 /**
  * Every webbeans component has an associated context that are
  * defined by the {@link ScopeType} annotation. Webbeans components
  * that are contained in the context are managed by the webbeans container.
  * 
  * <p>
@@ -16,11 +16,11 @@
 /**
  * Every webbeans component has an associated context that are
- * defined by the {@link ScopeType} annotation. Webbeans components
+ * defined by the {@link NormalScope} annotation. Webbeans components
  * that are contained in the context are managed by the webbeans container.
  * 

Modified: incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/spi/BeanManager.java
URL: http://svn.apache.org/viewvc/incubator/openwebbeans/trunk/webbeans-api/src/main/java/javax/enterprise/inject/spi/BeanManager.java?rev=809329&r1=809328&r2=809329&view=diff
==============================================================================